@@ -26,7 +26,7 @@ import os
 from datetime import datetime, timedelta
 from hashlib import sha1
 from io import BytesIO
-from typing import TYPE_CHECKING, ClassVar
+from typing import ClassVar
 
 import pyrogram
 from pyrogram import raw
@@ -44,9 +44,7 @@ from pyrogram.raw.all import layer
 from pyrogram.raw.core import FutureSalts, Int, MsgContainer, TLObject
 
 from .internals import MsgFactory, MsgId
-
-if TYPE_CHECKING:
-    from pyrogram.connection import Connection
+from pyrogram.connection import Connection
 
 log = logging.getLogger(__name__)
 
